@@ -4,11 +4,15 @@ from tempfile import gettempdir
 TEMP = gettempdir()
 
 try:
-    from django.conf.settings import *
+    from django.conf import settings
+
+    TEMP = settings.TEMP
 except ModuleNotFoundError:
     pass
 
 try:
-    from chalicelib.settings import *
+    from chalicelib import settings
+
+    TEMP = settings.TEMP
 except ModuleNotFoundError:
     pass
